## 📝 Description

<!-- Provide a concise explanation of the changes. -->
<!-- Example: Added a new CLI option to export results as JSON. -->

## 🎯 Motivation and Context

<!-- Why is this change necessary? What problem does it solve? -->
<!-- Example: Fixes issue #42 related to inconsistent JSON exports. -->

## 🔍 Changes Made

<!-- List key changes in bullet form. -->
- Added `--export-json` flag to CLI.
- Refactored `export.py` to support multiple formats.
- Updated tests to cover new feature.

## ✅ Checklist

- [ ] My code follows the code style of this project.
- [ ] I have added or updated tests.
- [ ] I have updated the documentation if applicable.
- [ ] I have linked to any relevant issues (e.g. `Fixes #123`).
- [ ] All CI checks have passed locally (e.g. `make check`, `make format`, `make test`, etc).

## 🧪 Testing

<!-- Describe how you tested this change and what QA steps should be taken. -->
<!-- Example: Ran `pytest` locally and verified CLI output manually. -->

## 📸 Screenshots / Logs (if applicable)

<!-- Attach screenshots, terminal output, or logs if helpful for review. -->

## 📎 Related Issues

<!-- Link related issues, pull requests, or discussions. -->
<!-- Example: See also #41 for previous discussion. -->

---

